@@ -25,6 +25,7 @@
  * $Name: not supported by cvs2svn $
  */
 
+#define _XOPEN_SOURCE
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -114,7 +115,7 @@ static PilPrintFunc _pil_message_printer = NULL;
 static PilPrintFunc _pil_error_printer = NULL;
 
 
-inline static void
+ static void
 _pil_message_print(const char *message)
 {
 
@@ -126,7 +127,7 @@ _pil_message_print(const char *message)
 }
 
 
-inline static void
+ static void
 _pil_error_print(const char *message)
 {
 
@@ -227,7 +228,7 @@ _pil_printerr(const char *format, ...)
  */
 
 /*
-inline static void pilMsgChangeWidth(int i)
+ static void pilMsgChangeWidth(int i)
 {
   struct winsize win;
 
@@ -264,7 +265,7 @@ inline static void pilMsgChangeWidth(int i)
  * @see pilMsgEnableTerminal(), pilMsgEnableLog()
  */
 
-inline static void pilMsgOut(PilMsgSeverity severity,
+ static void pilMsgOut(PilMsgSeverity severity,
 			     const char *functionName, char *format,
 			     va_list al)
 {
